Simple, striped down `find` replacement for use on NAS or slow disk drives. Results may be faster than `find` on SSDs for deep but not shallow searches. 

The "-z/--zips" flag will allow you to search inside zip-like objects.

The "--hash" option accepts an absolute filepath to generate a hash to search against.
